@@ -45,6 +45,7 @@
 #include <gitypelib.h>
 #include <gitypes.h>
 #include <giunioninfo.h>
+#include <giversionmacros.h>
 #include <givfuncinfo.h>
 
 G_BEGIN_DECLS
@@ -92,57 +93,99 @@ typedef enum
 
 /* Repository */
 
+GI_AVAILABLE_IN_ALL
 GType         g_irepository_get_type      (void) G_GNUC_CONST;
+
+GI_AVAILABLE_IN_ALL
 GIRepository *g_irepository_get_default   (void);
+
+GI_AVAILABLE_IN_ALL
 void          g_irepository_prepend_search_path (const char *directory);
+
+GI_AVAILABLE_IN_1_36
 void          g_irepository_prepend_library_path (const char *directory);
+
+GI_AVAILABLE_IN_ALL
 GSList *      g_irepository_get_search_path     (void);
+
+GI_AVAILABLE_IN_ALL
 const char *  g_irepository_load_typelib  (GIRepository *repository,
 					   GITypelib     *typelib,
 					   GIRepositoryLoadFlags flags,
 					   GError      **error);
+
+GI_AVAILABLE_IN_ALL
 gboolean      g_irepository_is_registered (GIRepository *repository,
 					   const gchar  *namespace_,
 					   const gchar  *version);
+
+GI_AVAILABLE_IN_ALL
 GIBaseInfo *  g_irepository_find_by_name  (GIRepository *repository,
 					   const gchar  *namespace_,
 					   const gchar  *name);
+
+GI_AVAILABLE_IN_ALL
 GList *       g_irepository_enumerate_versions (GIRepository *repository,
 					        const gchar  *namespace_);
+
+GI_AVAILABLE_IN_ALL
 GITypelib *    g_irepository_require       (GIRepository *repository,
 					   const gchar  *namespace_,
 					   const gchar  *version,
 					   GIRepositoryLoadFlags flags,
 					   GError      **error);
+
+GI_AVAILABLE_IN_ALL
 GITypelib *    g_irepository_require_private (GIRepository  *repository,
 					     const gchar   *typelib_dir,
 					     const gchar   *namespace_,
 					     const gchar   *version,
 					     GIRepositoryLoadFlags flags,
 					     GError       **error);
+
+GI_AVAILABLE_IN_ALL
 gchar      ** g_irepository_get_dependencies (GIRepository *repository,
 					      const gchar  *namespace_);
+
+GI_AVAILABLE_IN_ALL
 gchar      ** g_irepository_get_loaded_namespaces (GIRepository *repository);
+
+GI_AVAILABLE_IN_ALL
 GIBaseInfo *  g_irepository_find_by_gtype (GIRepository *repository,
 					   GType         gtype);
+
+GI_AVAILABLE_IN_ALL
 gint          g_irepository_get_n_infos   (GIRepository *repository,
 					   const gchar  *namespace_);
+
+GI_AVAILABLE_IN_ALL
 GIBaseInfo *  g_irepository_get_info      (GIRepository *repository,
 					   const gchar  *namespace_,
 					   gint          index);
+
+GI_AVAILABLE_IN_ALL
 GIEnumInfo *  g_irepository_find_by_error_domain (GIRepository *repository,
 						  GQuark        domain);
+
+GI_AVAILABLE_IN_ALL
 const gchar * g_irepository_get_typelib_path   (GIRepository *repository,
 						const gchar  *namespace_);
+GI_AVAILABLE_IN_ALL
 const gchar * g_irepository_get_shared_library (GIRepository *repository,
 						const gchar  *namespace_);
+GI_AVAILABLE_IN_ALL
 const gchar * g_irepository_get_c_prefix (GIRepository *repository,
                                           const gchar  *namespace_);
+GI_AVAILABLE_IN_ALL
 const gchar * g_irepository_get_version (GIRepository *repository,
 					 const gchar  *namespace_);
 
+
+GI_AVAILABLE_IN_ALL
 GOptionGroup * g_irepository_get_option_group (void);
 
+
+GI_AVAILABLE_IN_ALL
 gboolean       g_irepository_dump  (const char *arg, GError **error);
 
 /**
@@ -175,11 +218,13 @@ typedef enum
  */
 #define G_IREPOSITORY_ERROR (g_irepository_error_quark ())
 
+GI_AVAILABLE_IN_ALL
 GQuark g_irepository_error_quark (void);
 
 
 /* Global utility functions */
 
+GI_AVAILABLE_IN_ALL
 void gi_cclosure_marshal_generic (GClosure       *closure,
                                   GValue         *return_gvalue,
                                   guint           n_param_values,
