@@ -10,146 +10,344 @@
 #include <string.h>
 #include <stdlib.h>
 
+#include "gitestmacros.h"
+
+_GI_TEST_EXTERN
 void regress_set_abort_on_error (gboolean abort_on_error);
 
 /* basic types */
+_GI_TEST_EXTERN
 gboolean regress_test_boolean (gboolean in);
+
+_GI_TEST_EXTERN
 gboolean regress_test_boolean_true (gboolean in);
+
+_GI_TEST_EXTERN
 gboolean regress_test_boolean_false (gboolean in);
+
+_GI_TEST_EXTERN
 gint8 regress_test_int8 (gint8 in);
+
+_GI_TEST_EXTERN
 guint8 regress_test_uint8 (guint8 in);
+
+_GI_TEST_EXTERN
 gint16 regress_test_int16 (gint16 in);
+
+_GI_TEST_EXTERN
 guint16 regress_test_uint16 (guint16 in);
+
+_GI_TEST_EXTERN
 gint32 regress_test_int32 (gint32 in);
+
+_GI_TEST_EXTERN
 guint32 regress_test_uint32 (guint32 in);
+
+_GI_TEST_EXTERN
 gint64 regress_test_int64 (gint64 in);
+
+_GI_TEST_EXTERN
 guint64 regress_test_uint64 (guint64 in);
+
+_GI_TEST_EXTERN
 gshort regress_test_short (gshort in);
+
+_GI_TEST_EXTERN
 gushort regress_test_ushort (gushort in);
+
+_GI_TEST_EXTERN
 gint regress_test_int (gint in);
+
+_GI_TEST_EXTERN
 guint regress_test_uint (guint in);
+
+_GI_TEST_EXTERN
 glong regress_test_long (glong in);
+
+_GI_TEST_EXTERN
 gulong regress_test_ulong (gulong in);
+
+_GI_TEST_EXTERN
 gssize regress_test_ssize (gssize in);
+
+_GI_TEST_EXTERN
 gsize regress_test_size (gsize in);
+
+_GI_TEST_EXTERN
 gfloat regress_test_float (gfloat in);
+
+_GI_TEST_EXTERN
 gdouble regress_test_double (gdouble in);
+
+_GI_TEST_EXTERN
 gunichar regress_test_unichar (gunichar in);
+
+_GI_TEST_EXTERN
 time_t regress_test_timet (time_t in);
+
+_GI_TEST_EXTERN
 GType regress_test_gtype (GType in);
 
 /* utf8 */
+_GI_TEST_EXTERN
 const char *regress_test_utf8_const_return (void);
+
+_GI_TEST_EXTERN
 char *regress_test_utf8_nonconst_return (void);
+
+_GI_TEST_EXTERN
 void regress_test_utf8_const_in (const char *in);
+
+_GI_TEST_EXTERN
 void regress_test_utf8_out (char **out);
+
+_GI_TEST_EXTERN
 void regress_test_utf8_inout (char **inout);
+
+_GI_TEST_EXTERN
 GSList *regress_test_filename_return (void);
+
+_GI_TEST_EXTERN
 void regress_test_utf8_null_in (char *in);
+
+_GI_TEST_EXTERN
 void regress_test_utf8_null_out (char **char_out);
 
 /* in arguments after out arguments */
+_GI_TEST_EXTERN
 void regress_test_int_out_utf8 (int *length, const char *in);
 
 /* multiple output arguments */
+
+_GI_TEST_EXTERN
 void regress_test_multi_double_args (gdouble in, gdouble *one, gdouble *two);
+
+_GI_TEST_EXTERN
 void regress_test_utf8_out_out (char **out0, char **out1);
+
+_GI_TEST_EXTERN
 char *regress_test_utf8_out_nonconst_return (char **out);
 
 /* non-basic-types */
 /* array */
+_GI_TEST_EXTERN
 gboolean regress_test_strv_in (char **arr);
+
+_GI_TEST_EXTERN
 int regress_test_array_int_in (int n_ints, int *ints);
+
+_GI_TEST_EXTERN
 void regress_test_array_int_out (int *n_ints, int **ints);
+
+_GI_TEST_EXTERN
 void regress_test_array_int_inout (int *n_ints, int **ints);
+
+_GI_TEST_EXTERN
 int regress_test_array_gint8_in (int n_ints, gint8 *ints);
+
+_GI_TEST_EXTERN
 int regress_test_array_gint16_in (int n_ints, gint16 *ints);
+
+_GI_TEST_EXTERN
 gint32 regress_test_array_gint32_in (int n_ints, gint32 *ints);
+
+_GI_TEST_EXTERN
 gint64 regress_test_array_gint64_in (int n_ints, gint64 *ints);
+
+_GI_TEST_EXTERN
 char *regress_test_array_gtype_in (int n_types, GType *types);
+
+_GI_TEST_EXTERN
 char **regress_test_strv_out_container (void);
+
+_GI_TEST_EXTERN
 char **regress_test_strv_out (void);
+
+_GI_TEST_EXTERN
 const char * const * regress_test_strv_out_c (void);
+
+_GI_TEST_EXTERN
 void   regress_test_strv_outarg (char ***retp);
+
+_GI_TEST_EXTERN
 int regress_test_array_fixed_size_int_in (int *ints);
+
+_GI_TEST_EXTERN
 void regress_test_array_fixed_size_int_out (int **ints);
+
+_GI_TEST_EXTERN
 int *regress_test_array_fixed_size_int_return (void);
 
 /* transfer tests */
+_GI_TEST_EXTERN
 int *regress_test_array_int_full_out(int *len);
+
+_GI_TEST_EXTERN
 int *regress_test_array_int_none_out(int *len);
+
+_GI_TEST_EXTERN
 void regress_test_array_int_null_in (int *arr, int len);
+
+_GI_TEST_EXTERN
 void regress_test_array_int_null_out (int **arr, int *len);
 
 /* interface */
 /* GList */
+_GI_TEST_EXTERN
 const GList *regress_test_glist_nothing_return (void);
+
+_GI_TEST_EXTERN
 GList *regress_test_glist_nothing_return2 (void);
+
+_GI_TEST_EXTERN
 GList *regress_test_glist_container_return (void);
+
+_GI_TEST_EXTERN
 GList *regress_test_glist_everything_return (void);
+
+_GI_TEST_EXTERN
 void regress_test_glist_nothing_in (const GList *in);
+
+_GI_TEST_EXTERN
 void regress_test_glist_nothing_in2 (GList *in);
+
+_GI_TEST_EXTERN
 void regress_test_glist_null_in(GSList *in);
+
+_GI_TEST_EXTERN
 void regress_test_glist_null_out(GSList **out_list);
 
 /* GSList */
+_GI_TEST_EXTERN
 const GSList *regress_test_gslist_nothing_return (void);
+
+_GI_TEST_EXTERN
 GSList *regress_test_gslist_nothing_return2 (void);
+
+_GI_TEST_EXTERN
 GSList *regress_test_gslist_container_return (void);
+
+_GI_TEST_EXTERN
 GSList *regress_test_gslist_everything_return (void);
+
+_GI_TEST_EXTERN
 void regress_test_gslist_nothing_in (const GSList *in);
+
+_GI_TEST_EXTERN
 void regress_test_gslist_nothing_in2 (GSList *in);
+
+_GI_TEST_EXTERN
 void regress_test_gslist_null_in(GSList *in);
+
+_GI_TEST_EXTERN
 void regress_test_gslist_null_out(GSList **out_list);
 
 /* GHashTable */
+_GI_TEST_EXTERN
 const GHashTable *regress_test_ghash_null_return (void);
+
+_GI_TEST_EXTERN
 const GHashTable *regress_test_ghash_nothing_return (void);
+
+_GI_TEST_EXTERN
 GHashTable *regress_test_ghash_nothing_return2 (void);
+
+_GI_TEST_EXTERN
 GHashTable *regress_test_ghash_gvalue_return (void);
+
+_GI_TEST_EXTERN
 void regress_test_ghash_gvalue_in (GHashTable *hash);
+
+_GI_TEST_EXTERN
 GHashTable *regress_test_ghash_container_return (void);
+
+_GI_TEST_EXTERN
 GHashTable *regress_test_ghash_everything_return (void);
+
+_GI_TEST_EXTERN
 void regress_test_ghash_null_in (const GHashTable *in);
+
+_GI_TEST_EXTERN
 void regress_test_ghash_null_out (const GHashTable **out);
+
+_GI_TEST_EXTERN
 void regress_test_ghash_nothing_in (const GHashTable *in);
+
+_GI_TEST_EXTERN
 void regress_test_ghash_nothing_in2 (GHashTable *in);
+
+_GI_TEST_EXTERN
 GHashTable *regress_test_ghash_nested_everything_return (void);
+
+_GI_TEST_EXTERN
 GHashTable *regress_test_ghash_nested_everything_return2 (void);
 
 /* GPtrArray */
+_GI_TEST_EXTERN
 GPtrArray *regress_test_garray_container_return (void);
+
+_GI_TEST_EXTERN
 GPtrArray *regress_test_garray_full_return (void);
 
 /* error? */
 
 /* closure */
+_GI_TEST_EXTERN
 int regress_test_closure (GClosure *closure);
+
+_GI_TEST_EXTERN
 int regress_test_closure_one_arg (GClosure *closure, int arg);
+
+_GI_TEST_EXTERN
 GVariant *regress_test_closure_variant (GClosure *closure, GVariant* arg);
 
 /* value */
+_GI_TEST_EXTERN
 int regress_test_int_value_arg(const GValue *v);
+
+_GI_TEST_EXTERN
 const GValue *regress_test_value_return(int i);
 
 /* foreign structs */
 #ifndef _GI_DISABLE_CAIRO
+_GI_TEST_EXTERN
 cairo_t *regress_test_cairo_context_full_return (void);
+
+_GI_TEST_EXTERN
 void regress_test_cairo_context_none_in (cairo_t *context);
 
+
+_GI_TEST_EXTERN
 cairo_surface_t *regress_test_cairo_surface_none_return (void);
+
+_GI_TEST_EXTERN
 cairo_surface_t *regress_test_cairo_surface_full_return (void);
+
+_GI_TEST_EXTERN
 void regress_test_cairo_surface_none_in (cairo_surface_t *surface);
+
+_GI_TEST_EXTERN
 void regress_test_cairo_surface_full_out (cairo_surface_t **surface);
 #endif
 
 /* versioning (deprecated, since, stability) */
+_GI_TEST_EXTERN
 void regress_test_versioning (void);
 
+
+_GI_TEST_EXTERN
 GVariant *regress_test_gvariant_i (void);
+
+_GI_TEST_EXTERN
 GVariant *regress_test_gvariant_s (void);
+
+_GI_TEST_EXTERN
 GVariant *regress_test_gvariant_asv (void);
+
+_GI_TEST_EXTERN
 GVariant *regress_test_gvariant_v (void);
+
+_GI_TEST_EXTERN
 GVariant *regress_test_gvariant_as (void);
 
 /* enums / flags */
@@ -184,10 +382,15 @@ typedef enum
   REGRESS_TEST_FLAG3 = 1 << 2,
 } RegressTestFlags;
 
+_GI_TEST_EXTERN
 GType regress_test_enum_get_type (void) G_GNUC_CONST;
 #define REGRESS_TEST_TYPE_ENUM (regress_test_enum_get_type ())
+
+_GI_TEST_EXTERN
 GType regress_test_enum_unsigned_get_type (void) G_GNUC_CONST;
 #define REGRESS_TEST_TYPE_ENUM_UNSIGNED (regress_test_enum_unsigned_get_type ())
+
+_GI_TEST_EXTERN
 GType regress_test_flags_get_type (void) G_GNUC_CONST;
 #define REGRESS_TEST_TYPE_FLAGS (regress_test_flags_get_type ())
 
@@ -209,9 +412,14 @@ typedef enum
   REGRESS_TEST_EVALUE3 = '0'
 } RegressTestEnumNoGEnum;
 
+_GI_TEST_EXTERN
 const gchar * regress_test_enum_param(RegressTestEnum e);
+
+_GI_TEST_EXTERN
 const gchar * regress_test_unsigned_enum_param(RegressTestEnumUnsigned e);
 
+
+_GI_TEST_EXTERN
 void regress_global_get_flags_out (RegressTestFlags *v);
 
 /* error domains */
@@ -223,7 +431,10 @@ typedef enum
   REGRESS_TEST_ERROR_CODE3 = 3
 } RegressTestError;
 
+_GI_TEST_EXTERN
 GType regress_test_error_get_type (void);
+
+_GI_TEST_EXTERN
 GQuark regress_test_error_quark (void);
 
 /* Test weird names, with and without
@@ -236,7 +447,10 @@ typedef enum
   REGRESS_TEST_ABC_ERROR_CODE3 = 3
 } RegressTestABCError;
 
+_GI_TEST_EXTERN
 GType regress_test_abc_error_get_type (void);
+
+_GI_TEST_EXTERN
 GQuark regress_test_abc_error_quark (void);
 
 typedef enum
@@ -250,7 +464,10 @@ typedef enum
    The difference is intentional, although it
    is mainly meant for capitalization problems.
 */
+_GI_TEST_EXTERN
 GType regress_test_unconventional_error_get_type (void);
+
+_GI_TEST_EXTERN
 GQuark regress_test_unconventional_error_quark (void);
 
 typedef enum
@@ -260,6 +477,7 @@ typedef enum
   REGRESS_TEST_DEF_ERROR_CODE2 = 2
 } RegressTestDEFError;
 
+_GI_TEST_EXTERN
 GQuark regress_test_def_error_quark (void);
 
 /* the scanner used to have problem
@@ -273,6 +491,7 @@ typedef enum
   REGRESS_ATEST_ERROR_CODE2 = 2
 } RegressATestError;
 
+_GI_TEST_EXTERN
 GQuark regress_atest_error_quark (void);
 
 
@@ -305,8 +524,11 @@ struct _RegressTestStructA
   RegressTestEnum some_enum;
 };
 
+_GI_TEST_EXTERN
 void regress_test_struct_a_clone (RegressTestStructA *a,
 				  RegressTestStructA *a_out);
+
+_GI_TEST_EXTERN
 void regress_test_struct_a_parse (RegressTestStructA *a_out, const gchar *string);
 
 struct _RegressTestStructB
@@ -315,6 +537,7 @@ struct _RegressTestStructB
   RegressTestStructA nested_a;
 };
 
+_GI_TEST_EXTERN
 void regress_test_struct_b_clone (RegressTestStructB *b,
 			  RegressTestStructB *b_out);
 
@@ -386,10 +609,17 @@ struct _RegressTestSimpleBoxedA
 };
 
 /* Intentionally uses _get_gtype */
+_GI_TEST_EXTERN
 GType                   regress_test_simple_boxed_a_get_gtype     (void);
+
+_GI_TEST_EXTERN
 RegressTestSimpleBoxedA *regress_test_simple_boxed_a_copy         (RegressTestSimpleBoxedA *a);
+
+_GI_TEST_EXTERN
 gboolean                regress_test_simple_boxed_a_equals       (RegressTestSimpleBoxedA *a,
                                                           RegressTestSimpleBoxedA *other_a);
+
+_GI_TEST_EXTERN
 const RegressTestSimpleBoxedA *regress_test_simple_boxed_a_const_return (void);
 
 
@@ -399,7 +629,11 @@ struct _RegressTestSimpleBoxedB
   RegressTestSimpleBoxedA nested_a;
 };
 
+
+_GI_TEST_EXTERN
 GType             regress_test_simple_boxed_b_get_type (void);
+
+_GI_TEST_EXTERN
 RegressTestSimpleBoxedB *regress_test_simple_boxed_b_copy     (RegressTestSimpleBoxedB *b);
 
 /* opaque boxed */
@@ -416,17 +650,34 @@ struct _RegressTestBoxed
   RegressTestBoxedPrivate *priv;
 };
 
+_GI_TEST_EXTERN
 GType      regress_test_boxed_get_type (void);
+
+_GI_TEST_EXTERN
 RegressTestBoxed *regress_test_boxed_new      (void);
+
+_GI_TEST_EXTERN
 RegressTestBoxed *regress_test_boxed_new_alternative_constructor1  (int i);
+
+_GI_TEST_EXTERN
 RegressTestBoxed *regress_test_boxed_new_alternative_constructor2  (int i, int j);
+
+_GI_TEST_EXTERN
 RegressTestBoxed *regress_test_boxed_new_alternative_constructor3  (char *s);
 
+
+_GI_TEST_EXTERN
 RegressTestBoxed *regress_test_boxed_copy     (RegressTestBoxed *boxed);
+
+_GI_TEST_EXTERN
 gboolean   regress_test_boxed_equals   (RegressTestBoxed *boxed,
 					RegressTestBoxed *other);
 
+
+_GI_TEST_EXTERN
 void       regress_test_boxeds_not_a_method (RegressTestBoxed *boxed);
+
+_GI_TEST_EXTERN
 void       regress_test_boxeds_not_a_static (void);
 
 typedef struct _RegressTestBoxedB RegressTestBoxedB;
@@ -437,8 +688,14 @@ struct _RegressTestBoxedB
   glong some_long;
 };
 
+
+_GI_TEST_EXTERN
 GType regress_test_boxed_b_get_type (void);
+
+_GI_TEST_EXTERN
 RegressTestBoxedB *regress_test_boxed_b_new (gint8 some_int8, glong some_long);
+
+_GI_TEST_EXTERN
 RegressTestBoxedB *regress_test_boxed_b_copy (RegressTestBoxedB *boxed);
 
 typedef struct _RegressTestBoxedC RegressTestBoxedC;
@@ -449,17 +706,30 @@ struct _RegressTestBoxedC
   guint another_thing;
 };
 
+_GI_TEST_EXTERN
 GType regress_test_boxed_c_get_type (void);
+
+_GI_TEST_EXTERN
 RegressTestBoxedC *regress_test_boxed_c_new (void);
 
 typedef struct _RegressTestBoxedD RegressTestBoxedD;
 
+
+_GI_TEST_EXTERN
 GType regress_test_boxed_d_get_type (void);
 
+
+_GI_TEST_EXTERN
 RegressTestBoxedD *regress_test_boxed_d_new (const char *a_string, int a_int);
+
+_GI_TEST_EXTERN
 RegressTestBoxedD *regress_test_boxed_d_copy (RegressTestBoxedD *boxed);
+
+_GI_TEST_EXTERN
 void regress_test_boxed_d_free (RegressTestBoxedD *boxed);
 
+
+_GI_TEST_EXTERN
 int regress_test_boxed_d_get_magic (RegressTestBoxedD *boxed);
 
 /* gobject */
@@ -517,22 +787,51 @@ struct _RegressTestObjClass
   void (*_regress_reserved2) (void);
 };
 
+_GI_TEST_EXTERN
 GType      regress_test_obj_get_type (void);
+
+_GI_TEST_EXTERN
 RegressTestObj*   regress_test_obj_new (RegressTestObj *obj);
+
+_GI_TEST_EXTERN
 RegressTestObj*   regress_constructor (void);
+
+_GI_TEST_EXTERN
 RegressTestObj*   regress_test_obj_new_from_file (const char *x, GError **error);
+
+_GI_TEST_EXTERN
 void       regress_test_obj_set_bare (RegressTestObj *obj, GObject *bare);
+
+_GI_TEST_EXTERN
 void       regress_test_obj_emit_sig_with_obj (RegressTestObj *obj);
+
+_GI_TEST_EXTERN
 void       regress_test_obj_emit_sig_with_foreign_struct (RegressTestObj *obj);
+
+_GI_TEST_EXTERN
 void       regress_test_obj_emit_sig_with_int64 (RegressTestObj *obj);
+
+_GI_TEST_EXTERN
 void       regress_test_obj_emit_sig_with_uint64 (RegressTestObj *obj);
+
+_GI_TEST_EXTERN
 int        regress_test_obj_instance_method (RegressTestObj *obj);
+
+_GI_TEST_EXTERN
 void       regress_test_obj_instance_method_full (RegressTestObj *obj);
+
+_GI_TEST_EXTERN
 double     regress_test_obj_static_method (int x);
+
+_GI_TEST_EXTERN
 void       regress_forced_method (RegressTestObj *obj);
 
+
+_GI_TEST_EXTERN
 void regress_test_array_fixed_out_objects (RegressTestObj ***objs);
 
+
+_GI_TEST_EXTERN
 void regress_test_obj_torture_signature_0 (RegressTestObj    *obj,
                                    int        x,
                                    double     *y,
@@ -540,6 +839,8 @@ void regress_test_obj_torture_signature_0 (RegressTestObj    *obj,
                                    const char *foo,
                                    int        *q,
                                    guint       m);
+
+_GI_TEST_EXTERN
 gboolean regress_test_obj_torture_signature_1 (RegressTestObj    *obj,
                                        int        x,
                                        double     *y,
@@ -549,6 +850,8 @@ gboolean regress_test_obj_torture_signature_1 (RegressTestObj    *obj,
                                        guint       m,
                                        GError    **error);
 
+
+_GI_TEST_EXTERN
 gboolean regress_test_obj_skip_return_val (RegressTestObj *obj,
                                            gint            a,
                                            gint           *out_b,
@@ -559,10 +862,14 @@ gboolean regress_test_obj_skip_return_val (RegressTestObj *obj,
                                            gint            num2,
                                            GError        **error);
 
+
+_GI_TEST_EXTERN
 gboolean regress_test_obj_skip_return_val_no_out (RegressTestObj *obj,
                                                   gint            a,
                                                   GError        **error);
 
+
+_GI_TEST_EXTERN
 gboolean regress_test_obj_skip_param (RegressTestObj *obj,
                                       gint            a,
                                       gint           *out_b,
@@ -573,6 +880,8 @@ gboolean regress_test_obj_skip_param (RegressTestObj *obj,
                                       gint            num2,
                                       GError        **error);
 
+
+_GI_TEST_EXTERN
 gboolean regress_test_obj_skip_out_param (RegressTestObj *obj,
                                           gint            a,
                                           gint           *out_b,
@@ -583,6 +892,8 @@ gboolean regress_test_obj_skip_out_param (RegressTestObj *obj,
                                           gint            num2,
                                           GError        **error);
 
+
+_GI_TEST_EXTERN
 gboolean regress_test_obj_skip_inout_param (RegressTestObj *obj,
                                             gint            a,
                                             gint           *out_b,
@@ -594,9 +905,14 @@ gboolean regress_test_obj_skip_inout_param (RegressTestObj *obj,
                                             GError        **error);
 
 /* virtual */
+_GI_TEST_EXTERN
 int        regress_test_obj_do_matrix (RegressTestObj *obj, const char *somestr);
 
+
+_GI_TEST_EXTERN
 void regress_func_obj_null_in (RegressTestObj *obj);
+
+_GI_TEST_EXTERN
 void regress_test_obj_null_out (RegressTestObj **obj);
 
 /* inheritance */
@@ -618,9 +934,17 @@ struct _RegressTestSubObjClass
   RegressTestObjClass parent_class;
 };
 
+
+_GI_TEST_EXTERN
 GType       regress_test_sub_obj_get_type (void);
+
+_GI_TEST_EXTERN
 RegressTestObj* regress_test_sub_obj_new (void);
+
+_GI_TEST_EXTERN
 void        regress_test_sub_obj_unset_bare (RegressTestSubObj *obj);
+
+_GI_TEST_EXTERN
 int         regress_test_sub_obj_instance_method (RegressTestSubObj *obj);
 
 /* fundamental object */
@@ -656,13 +980,21 @@ struct _RegressTestFundamentalObjectClass {
   RegressTestFundamentalObjectFinalizeFunction finalize;
 };
 
+_GI_TEST_EXTERN
 GType 		       regress_test_fundamental_object_get_type (void);
+
+_GI_TEST_EXTERN
 RegressTestFundamentalObject* regress_test_fundamental_object_ref      (RegressTestFundamentalObject *fundamental_object);
+
+_GI_TEST_EXTERN
 void 		       regress_test_fundamental_object_unref 	(RegressTestFundamentalObject *fundamental_object);
 
 #define REGRESS_TEST_VALUE_HOLDS_FUNDAMENTAL_OBJECT(value)  (G_VALUE_HOLDS(value, REGRESS_TEST_TYPE_FUNDAMENTAL_OBJECT))
 
+_GI_TEST_EXTERN
 void 		       regress_test_value_set_fundamental_object (GValue *value, RegressTestFundamentalObject *fundamental_object);
+
+_GI_TEST_EXTERN
 RegressTestFundamentalObject* regress_test_value_get_fundamental_object (const GValue *value);
 
 typedef struct _RegressTestFundamentalSubObject RegressTestFundamentalSubObject;
@@ -678,8 +1010,12 @@ struct _RegressTestFundamentalSubObjectClass {
   RegressTestFundamentalObjectClass fundamental_object_class;
 };
 
+
+_GI_TEST_EXTERN
 GType regress_test_fundamental_sub_object_get_type(void);
 
+
+_GI_TEST_EXTERN
 RegressTestFundamentalSubObject *
 regress_test_fundamental_sub_object_new (const char *data);
 
@@ -713,35 +1049,81 @@ typedef int (*RegressTestCallbackFull) (int foo, double bar, char *path);
  * @two_length:
  */
 typedef int (*RegressTestCallbackArray) (int *one, gsize one_length, const char** two, int two_length);
+/**
+ * RegressTestCallbackArrayInOut:
+ * @ints: (inout) (array length=length):
+ * @length: (inout):
+ */
+typedef void (* RegressTestCallbackArrayInOut) (int **ints, int *length);
 
+_GI_TEST_EXTERN
 void regress_test_simple_callback (RegressTestSimpleCallback callback);
+
+_GI_TEST_EXTERN
 int regress_test_callback (RegressTestCallback callback);
+
+_GI_TEST_EXTERN
 int regress_test_multi_callback (RegressTestCallback callback);
+
+_GI_TEST_EXTERN
 int regress_test_array_callback (RegressTestCallbackArray callback);
+
+_GI_TEST_EXTERN
+int regress_test_array_inout_callback (RegressTestCallbackArrayInOut callback);
+
+_GI_TEST_EXTERN
 int regress_test_callback_user_data (RegressTestCallbackUserData callback,
                              gpointer user_data);
+
+_GI_TEST_EXTERN
 int regress_test_callback_destroy_notify (RegressTestCallbackUserData callback,
                                   gpointer user_data,
                                   GDestroyNotify notify);
+
+_GI_TEST_EXTERN
 int regress_test_callback_destroy_notify_no_user_data (RegressTestCallbackUserData callback,
                                   GDestroyNotify notify);
+
+_GI_TEST_EXTERN
 int regress_test_callback_thaw_notifications (void);
 
+
+_GI_TEST_EXTERN
 void regress_test_callback_async (RegressTestCallbackUserData callback, gpointer user_data);
+
+_GI_TEST_EXTERN
 int regress_test_callback_thaw_async (void);
 
+
+_GI_TEST_EXTERN
 void regress_test_async_ready_callback (GAsyncReadyCallback callback);
 
+
+_GI_TEST_EXTERN
 void regress_test_obj_instance_method_callback (RegressTestObj *obj, RegressTestCallback callback);
+
+_GI_TEST_EXTERN
 void regress_test_obj_static_method_callback (RegressTestCallback callback);
+
+_GI_TEST_EXTERN
 RegressTestObj *regress_test_obj_new_callback (RegressTestCallbackUserData callback,
                                 gpointer user_data,
                                 GDestroyNotify notify);
+
+_GI_TEST_EXTERN
 void regress_test_hash_table_callback (GHashTable *data, RegressTestCallbackHashtable callback);
+
+_GI_TEST_EXTERN
 void regress_test_gerror_callback (RegressTestCallbackGError callback);
+
+_GI_TEST_EXTERN
 void regress_test_null_gerror_callback (RegressTestCallbackGError callback);
+
+_GI_TEST_EXTERN
 void regress_test_owned_gerror_callback (RegressTestCallbackOwnedGError callback);
 
+
+_GI_TEST_EXTERN
 void regress_test_skip_unannotated_callback (RegressTestCallback callback);
 
 typedef struct _RegressTestInterface RegressTestInterface;
@@ -758,6 +1140,7 @@ struct _RegressTestInterfaceIface {
     GTypeInterface base_iface;
 };
 
+_GI_TEST_EXTERN
 GType regress_test_interface_get_type (void) G_GNUC_CONST;
 
 /* gobject with non-standard prefix */
@@ -778,10 +1161,20 @@ typedef struct
   GObjectClass parent_class;
 } RegressTestWi8021xClass;
 
+
+_GI_TEST_EXTERN
 GType        regress_test_wi_802_1x_get_type (void);
+
+_GI_TEST_EXTERN
 RegressTestWi8021x* regress_test_wi_802_1x_new (void);
+
+_GI_TEST_EXTERN
 gboolean     regress_test_wi_802_1x_get_testbool (RegressTestWi8021x *obj);
+
+_GI_TEST_EXTERN
 void         regress_test_wi_802_1x_set_testbool (RegressTestWi8021x *obj, gboolean v);
+
+_GI_TEST_EXTERN
 int          regress_test_wi_802_1x_static_method (int x);
 
 /* floating gobject */
@@ -800,16 +1193,24 @@ typedef struct
   GInitiallyUnownedClass parent_class;
 } RegressTestFloatingClass;
 
+
+_GI_TEST_EXTERN
 GType        regress_test_floating_get_type (void);
+
+_GI_TEST_EXTERN
 RegressTestFloating* regress_test_floating_new (void);
 
 /* Function signature torture tests */
+
+_GI_TEST_EXTERN
 void regress_test_torture_signature_0 (int        x,
                                double     *y,
                                int        *z,
                                const char *foo,
                                int        *q,
                                guint       m);
+
+_GI_TEST_EXTERN
 gboolean regress_test_torture_signature_1 (int        x,
                                    double     *y,
                                    int        *z,
@@ -817,6 +1218,8 @@ gboolean regress_test_torture_signature_1 (int        x,
                                    int        *q,
                                    guint       m,
                                    GError    **error);
+
+_GI_TEST_EXTERN
 void regress_test_torture_signature_2 (int                  x,
 				       RegressTestCallbackUserData  callback,
 				       gpointer              user_data,
@@ -827,12 +1230,22 @@ void regress_test_torture_signature_2 (int                  x,
 				       int                  *q,
 				       guint                 m);
 
+
+_GI_TEST_EXTERN
 GValue *regress_test_date_in_gvalue (void);
+
+_GI_TEST_EXTERN
 GValue *regress_test_strv_in_gvalue (void);
 
+
+_GI_TEST_EXTERN
 GObject * _regress_this_is_a_private_symbol (void);
 
+
+_GI_TEST_EXTERN
 void regress_test_multiline_doc_comments (void);
+
+_GI_TEST_EXTERN
 void regress_test_nested_parameter (int a);
 
 /**
@@ -847,6 +1260,8 @@ typedef struct
   double v;
 } RegressSkippedStructure;
 
+
+_GI_TEST_EXTERN
 void regress_random_function_with_skipped_structure (int x,
 						     RegressSkippedStructure *foo,
 						     double v);
@@ -874,6 +1289,8 @@ typedef RegressIntset RegressIntSet;
  */
 typedef GPtrArray RegressPtrArrayAlias;
 
+
+_GI_TEST_EXTERN
 void regress_introspectable_via_alias (RegressPtrArrayAlias *data);
 
 /**
@@ -883,6 +1300,8 @@ void regress_introspectable_via_alias (RegressPtrArrayAlias *data);
  */
 typedef va_list RegressVaListAlias;
 
+
+_GI_TEST_EXTERN
 void regress_not_introspectable_via_alias (RegressVaListAlias ok);
 
 /**
@@ -892,6 +1311,8 @@ void regress_not_introspectable_via_alias (RegressVaListAlias ok);
  */
 typedef RegressTestBoxed RegressAliasedTestBoxed;
 
+
+_GI_TEST_EXTERN
 void regress_aliased_caller_alloc (RegressAliasedTestBoxed *boxed);
 
 /* private testing */
@@ -917,12 +1338,16 @@ typedef struct {
   gint array[10];
 } RegressTestStructFixedArray;
 
+
+_GI_TEST_EXTERN
 void regress_test_struct_fixed_array_frob (RegressTestStructFixedArray *str);
 
 typedef struct {
   gchar name[32];
 } RegressLikeXklConfigItem;
 
+
+_GI_TEST_EXTERN
 void regress_like_xkl_config_item_set_name (RegressLikeXklConfigItem *self,
                                             const char *name);
 
@@ -940,6 +1365,7 @@ void regress_like_xkl_config_item_set_name (RegressLikeXklConfigItem *self,
 	"POWERSHARE,PRODIGY,TLX,X400,GIF,CGM,WMF,BMP,MET,PMB,DIB,PICT,TIFF," \
 	"PDF,PS,JPEG,QTIME,MPEG,MPEG2,AVI,WAVE,AIFF,PCM,X509,PGP"
 
+_GI_TEST_EXTERN
 void regress_has_parameter_named_attrs (int        foo,
                                         gpointer   attributes);
 
